@@ -45,9 +45,6 @@
 ;; Declare functions from org-social-relay
 (declare-function org-social-relay--fetch-feeds "org-social-relay" (callback))
 
-;; Declare functions from org-social-parser
-(declare-function org-social-parser--extract-mentioned-urls "org-social-parser" (text))
-
 ;; Declare variables to avoid compilation warnings
 (defvar org-social-max-post-age-days)
 (defvar org-social-max-concurrent-downloads)
@@ -117,9 +114,7 @@ Returns an RFC 3339 formatted date string, or nil if filtering is disabled."
 (defun org-social-feed--filter-by-date (content start-date)
   "Filter CONTENT to only include posts newer than START-DATE.
 Returns filtered content with header + filtered posts.
-If START-DATE is nil, returns CONTENT unchanged.
-Supports both Org Social v1.6 format (ID in header) and legacy
-format (ID in properties)."
+If START-DATE is nil, returns CONTENT unchanged."
   (if (not start-date)
       content
     ;; Use org-social-partial-fetch for filtering logic
@@ -135,45 +130,22 @@ format (ID in properties)."
               ;; Parse and filter posts
               (goto-char header-end)
               (let ((filtered-posts '()))
-                ;; Match only level-2 posts (** followed by non-asterisk or newline)
-                (while (re-search-forward "^\\*\\*\\($\\|[^*]\\)" nil t)
-                  (let ((post-start (line-beginning-position))
-                        (id-from-header nil)
-                        (id-from-properties nil)
-                        (post-id nil))
-                    ;; Extract ID from header (v1.6 format: ** TIMESTAMP)
-                    (beginning-of-line)
-                    (when (looking-at "^\\*\\*\\s-+\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}T[0-9]\\{2\\}:[0-9]\\{2\\}:[0-9]\\{2\\}[+-][0-9]\\{2\\}\\(:[0-9]\\{2\\}\\|[0-9]\\{2\\}\\)\\)")
-                      (setq id-from-header (match-string 1)))
-                    (end-of-line)
-                    (forward-char)
-
-                    ;; Find post end first (needed for searching within post boundaries)
-                    (let ((post-end (save-excursion
-                                      (if (re-search-forward "^\\*\\*\\($\\|[^*]\\)" nil t)
-                                          (line-beginning-position)
-                                        (point-max)))))
-
-                      ;; Extract ID from properties (legacy format)
-                      (when (re-search-forward ":ID:\\s-*\\(.+\\)$" post-end t)
-                        (setq id-from-properties (match-string 1)))
-
-                      ;; Use ID from header if present, otherwise use ID from properties
-                      ;; This matches the parser behavior (org-social-parser.el)
-                      (setq post-id (or id-from-header id-from-properties))
-
-                      ;; Filter post by date if we have an ID
-                      (when post-id
+                (while (re-search-forward "^\\*\\*.*$" nil t)
+                  (let ((post-start (line-beginning-position)))
+                    ;; Find post ID
+                    (when (re-search-forward ":ID:\\s-*\\(.+\\)$" nil t)
+                      (let ((post-id (match-string 1)))
                         ;; Compare dates (RFC 3339 strings are lexicographically comparable)
                         ;; Include posts that are not too old AND not in the future
                         (when (and (not (string< post-id start-date))
                                    (string< post-id (format-time-string "%FT%T%z")))
-                          (goto-char post-start)
-                          (push (buffer-substring-no-properties post-start post-end)
-                                filtered-posts)))
-
-                      ;; Move to the end of this post for next iteration
-                      (goto-char post-end))))
+                          ;; Find post end (next ** or end of buffer)
+                          (let ((post-end (save-excursion
+                                            (if (re-search-forward "^\\*\\*.*$" nil t)
+						(line-beginning-position)
+                                              (point-max)))))
+                            (push (buffer-substring-no-properties post-start post-end)
+                                  filtered-posts)))))))
                 ;; Rebuild content
                 (if filtered-posts
                     (concat header "\n" (mapconcat #'identity (nreverse filtered-posts) ""))
@@ -330,15 +302,6 @@ When a download completes, the next pending item is automatically started."
       ;; Remove failed downloads
       (setq org-social-variables--queue
             (seq-filter (lambda (i) (not (eq (alist-get :status i) :error))) org-social-variables--queue))
-
-      ;; Check for remote migrations before processing feeds
-      (when (fboundp 'org-social-file--check-and-apply-remote-migrations)
-        (let ((feeds-data (mapcar (lambda (item)
-                                    (cons (alist-get :url item)
-                                          (alist-get :response item)))
-                                  org-social-variables--queue)))
-          (org-social-file--check-and-apply-remote-migrations feeds-data)))
-
       ;; Process the feeds
       (setq org-social-variables--feeds
             (mapcar (lambda (item)
@@ -356,11 +319,6 @@ When a download completes, the next pending item is automatically started."
                          (cons 'url url)
                          (cons 'posts posts))))
                     org-social-variables--queue))
-
-      ;; Load my profile fresh each time to avoid stale data
-      (when (fboundp 'org-social-parser--get-my-profile)
-        (setq org-social-variables--my-profile (org-social-parser--get-my-profile)))
-
       ;; Add own profile only if not already in feeds (relay might have already included it)
       (when (and org-social-variables--my-profile
                  (not (seq-find (lambda (feed)
@@ -371,37 +329,6 @@ When a download completes, the next pending item is automatically started."
       (message "All feeds downloaded!")
       (run-hooks 'org-social-after-fetch-posts-hook))))
 
-(defun org-social-feed--should-show-post (post)
-  "Determine if POST should be visible to the current user.
-Returns t if the post should be shown, nil otherwise.
-According to Org Social specification v1.5:
-- Posts without VISIBILITY property are public (always visible)
-- Posts with VISIBILITY:public are always visible
-- Posts with VISIBILITY:mention are only visible if:
-  * The user is the author, OR
-  * The user is mentioned in the post body
-- Posts with GROUP property ignore VISIBILITY (always visible to group members)"
-  (let ((visibility (alist-get 'visibility post))
-        (author-url (alist-get 'author-url post))
-        (text (alist-get 'text post))
-        (group (alist-get 'group post))
-        (my-url (alist-get 'url org-social-variables--my-profile)))
-    ;; Posts with GROUP property ignore VISIBILITY
-    (if group
-        t
-      ;; If no VISIBILITY property or VISIBILITY is "public", show the post
-      (if (or (not visibility)
-              (string= visibility "public"))
-          t
-        ;; If VISIBILITY is "mention", check if we're the author or mentioned
-        (when (string= visibility "mention")
-          (or
-           ;; We are the author
-           (and my-url author-url (string= my-url author-url))
-           ;; We are mentioned in the post body
-           (and my-url text
-                (member my-url (org-social-parser--extract-mentioned-urls text)))))))))
-
 (defun org-social-feed--get-timeline ()
   "Get all posts from all feeds sorted by date."
   (let* ((timeline (mapcan (lambda (feed)
@@ -424,9 +351,8 @@ According to Org Social specification v1.5:
                                           ;; Keep posts with text (reactions are filtered out)
                                           ;; Keep boosts (posts with INCLUDE property)
                                           ;; Exclude group posts (posts with GROUP property)
-                                          ;; Exclude reactions (posts with reply_to + mood but NO text)
+                                          ;; Exclude reactions (posts with reply_to + mood)
                                           ;; Filter by language if org-social-language-filter is set
-                                          ;; Filter by visibility (VISIBILITY:mention)
                                           (let ((text (alist-get 'text post))
                                                 (group (alist-get 'group post))
                                                 (mood (alist-get 'mood post))
@@ -434,13 +360,9 @@ According to Org Social specification v1.5:
                                                 (include (alist-get 'include post))
                                                 (lang (alist-get 'lang post)))
                                             ;; Exclude posts with GROUP property from timeline
-                                            ;; Exclude reactions (reply_to + mood + NO text)
+                                            ;; Exclude reactions (reply_to + mood)
                                             (and (not group)
-                                                 (not (and reply-to
-                                                           mood
-                                                           (not (string-empty-p mood))
-                                                           (or (not text)
-                                                               (string-empty-p (string-trim text)))))
+                                                 (not (and reply-to mood))
                                                  ;; Must have text OR be a boost (include)
                                                  (or (and text (not (string-empty-p (string-trim text))))
                                                      (and include (not (string-empty-p include))))
@@ -448,9 +370,7 @@ According to Org Social specification v1.5:
                                                  (or (null org-social-language-filter)
                                                      (and lang
                                                           (not (string-empty-p lang))
-                                                          (member lang org-social-language-filter)))
-                                                 ;; Filter by visibility
-                                                 (org-social-feed--should-show-post post))))
+                                                          (member lang org-social-language-filter))))))
                                         timeline))
          (timeline-sorted (sort timeline-filtered
                                 (lambda (a b)
