@@ -93,45 +93,33 @@ AUTHOR-URL and TIMESTAMP identify the poll.
 POLL-OPTION is the selected option."
   (require 'org-social-file)
   (require 'org-social-parser)
-  ;; Determine target file (handle vfile URLs)
-  (let ((target-file (if (and (fboundp 'org-social-file--is-vfile-p)
-                              (org-social-file--is-vfile-p org-social-file)
-                              (fboundp 'org-social-file--get-local-file-path))
-                         (org-social-file--get-local-file-path org-social-file)
-                       org-social-file)))
-    ;; Open social.org file (or local vfile cache)
-    (unless (and (buffer-file-name)
-                 (string= (expand-file-name (buffer-file-name))
-                          (expand-file-name target-file)))
-      (find-file target-file))
-    ;; Find posts section
-    (goto-char (point-min))
-    (unless (re-search-forward "^\\* Posts" nil t)
-      (user-error "No '* Posts' section found in %s" target-file))
-    ;; Go to end of buffer to insert new post
-    (goto-char (point-max))
-    ;; Insert minimal vote template
-    (let ((vote-timestamp (org-social-parser--generate-timestamp)))
-      (insert "\n** \n:PROPERTIES:\n")
-      (insert (format ":ID: %s\n" vote-timestamp))
-      (insert ":CLIENT: org-social.el\n")
-      (insert (format ":REPLY_TO: %s#%s\n" author-url timestamp))
-      (insert (format ":POLL_OPTION: %s\n" poll-option))
-      (insert ":END:\n\n")
-      (save-buffer)
-      (message "Vote created for option: %s" poll-option))
-    ;; Sync to vfile host if using vfile
-    (when (and (fboundp 'org-social-file--is-vfile-p)
-               (org-social-file--is-vfile-p org-social-file)
-               (fboundp 'org-social-file--sync-vfile))
-      (org-social-file--sync-vfile))
-    ;; Move cursor to end and recenter
-    (goto-char (point-max))
-    (recenter -3)
-    ;; Validate file after adding vote
-    (when (fboundp 'org-social-validator-validate-and-display)
-      (require 'org-social-validator)
-      (org-social-validator-validate-and-display))))
+  ;; Open social.org file
+  (unless (and (buffer-file-name)
+               (string= (expand-file-name (buffer-file-name))
+                        (expand-file-name org-social-file)))
+    (find-file org-social-file))
+  ;; Find posts section
+  (goto-char (point-min))
+  (unless (re-search-forward "^\\* Posts" nil t)
+    (user-error "No '* Posts' section found in %s" org-social-file))
+  ;; Go to end of buffer to insert new post
+  (goto-char (point-max))
+  ;; Insert minimal vote template
+  (let ((vote-timestamp (org-social-parser--generate-timestamp)))
+    (insert "\n** \n:PROPERTIES:\n")
+    (insert (format ":ID: %s\n" vote-timestamp))
+    (insert ":CLIENT: org-social.el\n")
+    (insert (format ":REPLY_TO: %s#%s\n" author-url timestamp))
+    (insert (format ":POLL_OPTION: %s\n" poll-option))
+    (insert ":END:\n\n")
+    (message "Vote created for option: %s" poll-option))
+  ;; Move cursor to end and recenter
+  (goto-char (point-max))
+  (recenter -3)
+  ;; Validate file after adding vote
+  (when (fboundp 'org-social-validator-validate-and-display)
+    (require 'org-social-validator)
+    (org-social-validator-validate-and-display)))
 
 (defun org-social-ui--render-poll-content (text poll-end author-url timestamp _is-my-post)
   "Render poll content with interactive radio buttons.
@@ -224,20 +212,9 @@ _IS-MY-POST indicates if this is the current user's poll (unused for now)."
           (insert (propertize "Poll has ended" 'face '(:foreground "#888888" :slant italic)))
           (insert "\n"))))))
 
-(defun org-social-ui--maybe-truncate-text (text)
-  "Truncate TEXT if it exceeds `org-social-post-preview-length'.
-Returns a cons cell (DISPLAY-TEXT . FULL-TEXT).
-If text is truncated, DISPLAY-TEXT ends with ellipsis, otherwise both
-are the same."
-  (if (and org-social-post-preview-length
-           (> (length text) org-social-post-preview-length))
-      (cons (concat (substring text 0 org-social-post-preview-length) "...") text)
-    (cons text text)))
-
-(defun org-social-ui--post-component (post &optional _timeline-data no-truncate)
+(defun org-social-ui--post-component (post &optional _timeline-data)
   "Insert a post component for POST with optional TIMELINE-DATA (unused).
-Automatically fetches reactions from Relay if not present in POST.
-When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
+Automatically fetches reactions from Relay if not present in POST."
   ;; Ensure post has reactions (fetch if missing)
   (let* ((author-url-temp (or (alist-get 'author-url post)
                               (alist-get 'url post)))
@@ -310,14 +287,9 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
           (if poll-end
               ;; For polls, render with interactive radio buttons
               (org-social-ui--render-poll-content text poll-end author-url timestamp is-my-post)
-            ;; For regular posts, check if text should be truncated
-            (let* ((truncation-result (if no-truncate
-                                          (cons text text)
-                                        (org-social-ui--maybe-truncate-text text)))
-                   (display-text (car truncation-result))
-                   (full-text (cdr truncation-result))
-                   (org-content-start (point))
-                   (formatted-text (org-social-ui--format-org-headings display-text)))
+            ;; For regular posts, render as before
+            (let ((org-content-start (point))
+                  (formatted-text (org-social-ui--format-org-headings text)))
               (insert formatted-text)
               (insert "\n")
               ;; Mark region as interactive Org content
@@ -325,24 +297,13 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
                 ;; Use text properties to mark the region
                 (put-text-property org-content-start org-content-end
                                    'org-social-org-content t)
-                (put-text-property org-content-start org-content-end
-                                   'org-social-full-text full-text)
                 ;; Create overlay with keymap for higher priority in read-only buffers
                 (let ((keymap-overlay (make-overlay org-content-start org-content-end)))
                   (overlay-put keymap-overlay 'keymap org-social-ui--org-content-keymap)
                   (overlay-put keymap-overlay 'priority 50)
                   (overlay-put keymap-overlay 'org-social-keymap-overlay t))
                 ;; Apply 'org-mode' syntax highlighting to this region only
-                (org-social-ui--apply-org-mode-to-region org-content-start org-content-end))
-              ;; Add "Read more" button if text was truncated
-              (when (not (equal display-text full-text))
-                (org-social-ui--insert-formatted-text "\n")
-                (widget-create 'push-button
-                               :notify `(lambda (&rest _)
-                                          (org-social-ui-thread ,post-url-temp))
-                               :help-echo "Open full post in thread view"
-                               " 📖 Read more ")
-                (org-social-ui--insert-formatted-text "\n")))))
+                (org-social-ui--apply-org-mode-to-region org-content-start org-content-end)))))
 
 	;; 2.5. If this is a boost, show the original boosted post
 	(when (and include (not (string-empty-p include)))
@@ -354,15 +315,15 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
           ;; Fetch and display the original post
           (let ((original-post (org-social-ui--fetch-post-sync include)))
             (when original-post
-	      (let* ((orig-author (or (alist-get 'author-nick original-post)
-				      (alist-get 'nick original-post)
-				      "Unknown"))
+              (let* ((orig-author (or (alist-get 'author-nick original-post)
+                                      (alist-get 'nick original-post)
+                                      "Unknown"))
                      (orig-text (or (alist-get 'text original-post)
                                     (alist-get 'content original-post)
                                     ""))
                      (orig-avatar (or (alist-get 'author-avatar original-post)
-				      (alist-get 'avatar original-post)
-				      (alist-get 'feed-avatar original-post)))
+                                      (alist-get 'avatar original-post)
+                                      (alist-get 'feed-avatar original-post)))
                      (orig-timestamp (or (alist-get 'timestamp original-post)
                                          (alist-get 'id original-post)
                                          (alist-get 'date original-post)
@@ -370,9 +331,9 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
                 ;; Show original author info
                 (if (and orig-avatar (not (string-empty-p orig-avatar)))
                     (progn
-		      (org-social-ui--insert-formatted-text " ")
-		      (org-social-ui--put-image-from-cache orig-avatar (line-number-at-pos) 50)
-		      (org-social-ui--insert-formatted-text " "))
+                      (org-social-ui--insert-formatted-text " ")
+                      (org-social-ui--put-image-from-cache orig-avatar (line-number-at-pos) 50)
+                      (org-social-ui--insert-formatted-text " "))
                   (org-social-ui--insert-formatted-text "👤 " nil "#4a90e2"))
                 (org-social-ui--insert-formatted-text (format "%s" orig-author) 1.1 "#4a90e2")
                 (org-social-ui--insert-formatted-text " • ")
@@ -380,34 +341,18 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
                 (org-social-ui--insert-formatted-text "\n\n")
                 ;; Show original post content
                 (when (and orig-text (not (string-empty-p orig-text)))
-                  (let* ((truncation-result (if no-truncate
-                                                (cons orig-text orig-text)
-                                              (org-social-ui--maybe-truncate-text orig-text)))
-                         (display-text (car truncation-result))
-                         (full-text (cdr truncation-result))
-                         (orig-content-start (point))
-                         (formatted-text (org-social-ui--format-org-headings display-text)))
+                  (let ((orig-content-start (point))
+                        (formatted-text (org-social-ui--format-org-headings orig-text)))
                     (insert formatted-text)
                     (insert "\n")
                     (let ((orig-content-end (point)))
-		      (put-text-property orig-content-start orig-content-end
+                      (put-text-property orig-content-start orig-content-end
                                          'org-social-org-content t)
-		      (put-text-property orig-content-start orig-content-end
-                                         'org-social-full-text full-text)
-		      (let ((keymap-overlay (make-overlay orig-content-start orig-content-end)))
+                      (let ((keymap-overlay (make-overlay orig-content-start orig-content-end)))
                         (overlay-put keymap-overlay 'keymap org-social-ui--org-content-keymap)
                         (overlay-put keymap-overlay 'priority 50)
                         (overlay-put keymap-overlay 'org-social-keymap-overlay t))
-		      (org-social-ui--apply-org-mode-to-region orig-content-start orig-content-end))
-                    ;; Add "Read more" button if text was truncated
-                    (when (not (equal display-text full-text))
-		      (org-social-ui--insert-formatted-text "\n")
-		      (widget-create 'push-button
-                                     :notify `(lambda (&rest _)
-                                                (org-social-ui-thread ,include))
-                                     :help-echo "Open full post in thread view"
-                                     " 📖 Read more ")
-		      (org-social-ui--insert-formatted-text "\n"))))
+                      (org-social-ui--apply-org-mode-to-region orig-content-start orig-content-end))))
                 (org-social-ui--insert-formatted-text "────────────────\n" nil "#888888")
                 (org-social-ui--insert-formatted-text "\n")))))
 
@@ -417,8 +362,8 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
           ;; 4. Tags only
           (let ((tag-list (split-string tags "\\s-+" t)))
             (dolist (tag tag-list)
-	      (org-social-ui--insert-formatted-text (format "#%s" tag) nil org-social-hashtag-color)
-	      (org-social-ui--insert-formatted-text " ")))
+              (org-social-ui--insert-formatted-text (format "#%s" tag) nil org-social-hashtag-color)
+              (org-social-ui--insert-formatted-text " ")))
           (org-social-ui--insert-formatted-text "\n"))
 
 	;; Add line break before action buttons
@@ -430,8 +375,8 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
           (when poll-end
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (require 'org-social-polls)
-				      (org-social-polls--show-poll-results ,author-url ,timestamp))
+                                      (require 'org-social-polls)
+                                      (org-social-polls--show-poll-results ,author-url ,timestamp))
                            :help-echo "View poll results"
                            " 📊 ")
             (setq first-button nil))
@@ -441,7 +386,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (unless first-button (org-social-ui--insert-formatted-text " "))
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (org-social-file--edit-post ,timestamp))
+                                      (org-social-file--edit-post ,timestamp))
                            :help-echo "Edit this post"
                            " ✏️ ")
             (setq first-button nil))
@@ -451,7 +396,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (unless first-button (org-social-ui--insert-formatted-text " "))
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (org-social-file--new-post ,author-url ,timestamp))
+                                      (org-social-file--new-post ,author-url ,timestamp))
                            :help-echo "Reply to this post"
                            " ↳ ")
             (setq first-button nil))
@@ -462,20 +407,20 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
 		 (has-real-replies (org-social-ui--post-has-real-replies-p post-url))
 		 (thread-url (if has-reply-to reply-to post-url)))
             (when (or has-reply-to has-real-replies)
-	      (unless first-button (org-social-ui--insert-formatted-text " "))
-	      (widget-create 'push-button
+              (unless first-button (org-social-ui--insert-formatted-text " "))
+              (widget-create 'push-button
                              :notify `(lambda (&rest _)
 					(org-social-ui-thread ,thread-url))
                              :help-echo "View conversation thread"
                              " 🧵 ")
-	      (setq first-button nil)))
+              (setq first-button nil)))
 
           ;; Profile button (only for others' posts)
           (when (not is-my-post)
             (unless first-button (org-social-ui--insert-formatted-text " "))
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (org-social-ui-profile ,author-url))
+                                      (org-social-ui-profile ,author-url))
                            :help-echo "View user profile"
                            " 👤 ")
             (setq first-button nil))
@@ -485,7 +430,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (unless first-button (org-social-ui--insert-formatted-text " "))
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (org-social-ui--add-reaction ,author-url ,timestamp))
+                                      (org-social-ui--add-reaction ,author-url ,timestamp))
                            :help-echo "Add reaction to this post"
                            " 😊 ")
             (setq first-button nil))
@@ -496,7 +441,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (let ((boost-label (if (> boosts-count 0)
                                    (format " %d 🔄 " boosts-count)
                                  " 🔄 ")))
-	      (widget-create 'push-button
+              (widget-create 'push-button
                              :notify `(lambda (&rest _)
                                         (org-social-ui--boost-post ,author-url ,timestamp))
                              :help-echo "Boost (share) this post"
@@ -510,7 +455,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (unless first-button (org-social-ui--insert-formatted-text " "))
             (widget-create 'push-button
                            :notify `(lambda (&rest _)
-				      (org-social-ui--open-live-preview ,author-url ,timestamp))
+                                      (org-social-ui--open-live-preview ,author-url ,timestamp))
                            :help-echo "Share post preview link"
                            " 🔗 ")
             (setq first-button nil))
@@ -520,16 +465,16 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
             (let* ((current-col (current-column))
                    (target-col 70)
                    (spaces-needed (max 2 (- target-col current-col))))
-	      (org-social-ui--insert-formatted-text (make-string spaces-needed ?\s))
-	      (org-social-ui--insert-formatted-text mood nil "#ffaa00"))))
+              (org-social-ui--insert-formatted-text (make-string spaces-needed ?\s))
+              (org-social-ui--insert-formatted-text mood nil "#ffaa00"))))
 
 	;; 6. Display reactions if any (from Relay)
 	(let ((reactions-data (alist-get 'reactions post-with-reactions)))
           (if (and reactions-data (> (length reactions-data) 0))
-	      (progn
+              (progn
 		(org-social-ui--insert-formatted-text "\n\n")
 		(let ((first-item t)
-		      (reactions-list (if (vectorp reactions-data)
+                      (reactions-list (if (vectorp reactions-data)
                                           (append reactions-data nil)
                                         reactions-data)))
                   ;; Show reactions
@@ -537,7 +482,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
                     (let* ((emoji (cdr (assoc 'emoji reaction)))
                            (posts (cdr (assoc 'posts reaction)))
                            (count (if (vectorp posts) (length posts) (length posts))))
-		      (when (and emoji (> count 0))
+                      (when (and emoji (> count 0))
 			(unless first-item
                           (org-social-ui--insert-formatted-text " | " nil "#888888"))
 			;; Show emoji and count
@@ -552,9 +497,9 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
 	;; Avatar image
 	(if (and avatar (not (string-empty-p avatar)))
             (progn
-	      (org-social-ui--insert-formatted-text " ")
-	      (org-social-ui--put-image-from-cache avatar (line-number-at-pos) 50)
-	      (org-social-ui--insert-formatted-text " "))
+              (org-social-ui--insert-formatted-text " ")
+              (org-social-ui--put-image-from-cache avatar (line-number-at-pos) 50)
+              (org-social-ui--insert-formatted-text " "))
           ;; No avatar - show anonymous emoji
           (org-social-ui--insert-formatted-text "👤 " nil "#4a90e2"))
 
@@ -691,7 +636,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
 
   ;; Extract info from URL (format: https://domain.com/social.org#timestamp)
   (let ((author-url (when (string-match "\\(.*\\)#" mention-url)
-		      (match-string 1 mention-url)))
+                      (match-string 1 mention-url)))
         (timestamp (when (string-match "#\\(.+\\)$" mention-url)
                      (match-string 1 mention-url))))
 
@@ -713,7 +658,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
     ;; Action buttons
     (widget-create 'push-button
                    :notify `(lambda (&rest _)
-			      (org-social-ui-thread ,mention-url))
+                              (org-social-ui-thread ,mention-url))
                    :help-echo "View thread"
                    " 🧵 View Thread ")
 
@@ -734,9 +679,9 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
   (if mentions
       (progn
         (org-social-ui--insert-formatted-text (format "Found %d mention%s:\n\n"
-						      (length mentions)
-						      (if (= (length mentions) 1) "" "s"))
-					      nil "#4a90e2")
+                                                      (length mentions)
+                                                      (if (= (length mentions) 1) "" "s"))
+                                              nil "#4a90e2")
         (dolist (mention mentions)
           (org-social-ui--mention-component mention)))
     (org-social-ui--insert-formatted-text "No new mentions or replies found.\n" nil "#666666")
@@ -748,7 +693,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
   "Insert a group component for GROUP (can be string or object)."
   (let* ((group-name (if (stringp group)
                          group
-		       (or (alist-get 'name group) "Unknown")))
+                       (or (alist-get 'name group) "Unknown")))
          (description (if (stringp group)
                           "Group description"
                         (or (alist-get 'description group) "No description")))
@@ -757,7 +702,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
                          (or (alist-get 'members group) 0)))
          (post-count (if (stringp group)
                          0
-		       (or (alist-get 'posts group) 0))))
+                       (or (alist-get 'posts group) 0))))
 
     ;; Group header
     (org-social-ui--insert-formatted-text "👥 " 1.2 "#4a90e2")
@@ -784,7 +729,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
     (org-social-ui--insert-formatted-text "  ")
     (widget-create 'push-button
                    :notify `(lambda (&rest _)
-			      (org-social-ui-group-posts ,group-name))
+                              (org-social-ui-group-posts ,group-name))
                    :help-echo (format "View posts in %s group" group-name)
                    " 📄 View Posts ")
 
@@ -792,7 +737,7 @@ When NO-TRUNCATE is non-nil, the post is displayed in full without truncation."
 
     (widget-create 'push-button
                    :notify `(lambda (&rest _)
-			      (message "Joining group functionality - to be implemented"))
+                              (message "Joining group functionality - to be implemented"))
                    :help-echo (format "Join %s group" group-name)
                    " ➕ Join Group ")
 
