@@ -373,10 +373,15 @@ specifically for the timeline view."
         (setq org-social-variables--queue nil)
         (message "Cache cleared, loading fresh data from relay...")
 
-        ;; Load my profile first to get followers list
+        ;; Load my profile first to get followers list AND set org-social-variables--my-profile
         (when (fboundp 'org-social-file--read-my-profile)
           (org-social-file--read-my-profile))
 
+        ;; CRITICAL: Load my profile into org-social-variables--my-profile
+        (when (fboundp 'org-social-parser--get-my-profile)
+          (require 'org-social-parser)
+          (setq org-social-variables--my-profile (org-social-parser--get-my-profile)))
+
         ;; Initialize feeds from relay if available, otherwise from local followers
         (if (and (boundp 'org-social-relay)
                  org-social-relay
@@ -525,11 +530,7 @@ Only checks posts that will be visible on the current page."
                       (org-social-feed--get-timeline))))
       ;; Display timeline (reactions will be fetched automatically by post component)
       (org-social-ui--check-replies-and-display-timeline timeline)
-      (message "Timeline ready with %d posts" (if timeline (length timeline) 0))
-      ;; After timeline is displayed, update mentions cache in background
-      (when (fboundp 'org-social-file--update-mentions-cache-async)
-        (require 'org-social-file)
-        (org-social-file--update-mentions-cache-async)))))
+      (message "Timeline ready with %d posts" (if timeline (length timeline) 0)))))
 
 (defun org-social-ui--timeline-next-page ()
   "Load and append next page of posts (infinite scroll)."
